pub struct CorefResolver;Implementations
Sourceimpl CorefResolver
impl CorefResolver
Sourcepub fn resolve(text: &str, entities: &[ExtractedEntity]) -> Vec<ExtractedEntity>
pub fn resolve(text: &str, entities: &[ExtractedEntity]) -> Vec<ExtractedEntity>
Given the original text and a list of extracted entities (from NER), find pronoun spans and resolve them to the most recently mentioned compatible entity. Returns additional entity mentions to add.